@@ -5,10 +5,11 @@ use Mesos::Channel;
 use Scalar::Util qw(weaken);
 use Scope::Guard qw(guard);
 use Moo;
+use namespace::autoclean;
 
 =head1 NAME
 
-Mesos::Dispatcher
+Mesos::Dispatcher - base class for Mesos dispatchers
 
 =head1 DESCRIPTION
 
@@ -18,28 +19,40 @@ A parent class for event dispatchers to inherit from.
 
 =head2 channel
 
+A Mesos::Channel, used for sending event data from Mesos C++ callbacks to perl.
+
 =head2 cb
 
+A code ref to be invoked when an event is ready to be processed from the channel.
+
+Normally this will be set by Mesos::Role::HasDispatcher.
+
 =head1 METHODS
 
 =head2 new
 
     my $dispatcher = Mesos::Dispatcher->new(%args)
 
-        %args
-            REQUIRED cb
-            OPTIONAL channel
+        OPTIONAL %args
+            cb
+            channel
 
 =head2 call
 
+A shortcut for invoking the cb attribute.
+
 =head2 notify
 
 =head2 recv
 
+Receive event data from the channel. Returns undef if no event data is available.
+
 =head2 send
 
 =head2 wait
 
+Wait for an event to be sent to the channel, invoke the cb attribute, and return the event arguments.
+
 =cut
 
 has channel => (
