@@ -3,10 +3,11 @@
 namespace mesos {
 namespace perl {
 
-ExecutorDriver::ExecutorDriver()
+ExecutorDriver::ExecutorDriver(ProxyExecutor* proxyExecutor)
+: proxyExecutor_(proxyExecutor),
+  driver_(new MesosExecutorDriver(proxyExecutor_))
 {
-    proxyExecutor_ = new ProxyExecutor();
-    driver_ = new MesosExecutorDriver(proxyExecutor_);
+
 }
 
 ExecutorDriver::~ExecutorDriver()
@@ -15,11 +16,6 @@ ExecutorDriver::~ExecutorDriver()
     delete proxyExecutor_;
 }
 
-MesosChannel* ExecutorDriver::get_proxy_channel()
-{
-    return proxyExecutor_->channel_;
-}
-
 Status ExecutorDriver::start()
 {
     return status_ = driver_->start();
